@@ -51,6 +51,16 @@ func (fsys MapFsImpl) Open(path string) (fs.File, error) {
 	return WritableFile{result, fsys.MapFS, path}, err
 }
 
+func (fsys MapFsImpl) OpenAtEnd(path string) (fs.File, error) {
+	var file = fstest.MapFile{
+		Data: []byte("content2"),
+	}
+	fsys.MapFS[path] = &file
+
+	result, err := fsys.MapFS.Open(path)
+	return WritableFile{result, fsys.MapFS, path}, err
+}
+
 func TestNewArtifactUploadPrepare(t *testing.T) {
 	assert := assert.New(t)
 
@@ -259,6 +269,8 @@ func TestArtifactFlow(t *testing.T) {
 
 func runTestJobFile(ctx context.Context, t *testing.T, tjfi TestJobFileInfo) {
 	t.Run(tjfi.workflowPath, func(t *testing.T) {
+		fmt.Printf("::group::%s\n", tjfi.workflowPath)
+
 		if err := os.RemoveAll(aritfactsPath); err != nil {
 			panic(err)
 		}
@@ -292,5 +304,7 @@ func runTestJobFile(ctx context.Context, t *testing.T, tjfi TestJobFileInfo) {
 		} else {
 			assert.Error(t, err, tjfi.errorMessage)
 		}
+
+		fmt.Println("::endgroup::")
 	})
 }
