@@ -1,18 +1,20 @@
 package container
 
 import (
+	"context"
 	"strings"
 
 	"github.com/docker/cli/cli/config"
 	"github.com/docker/cli/cli/config/credentials"
 	"github.com/docker/docker/api/types"
-	log "github.com/sirupsen/logrus"
+	"github.com/nektos/act/pkg/common"
 )
 
-func LoadDockerAuthConfig(image string) (types.AuthConfig, error) {
+func LoadDockerAuthConfig(ctx context.Context, image string) (types.AuthConfig, error) {
+	logger := common.Logger(ctx)
 	config, err := config.Load(config.Dir())
 	if err != nil {
-		log.Warnf("Could not load docker config: %v", err)
+		logger.Warnf("Could not load docker config: %v", err)
 		return types.AuthConfig{}, err
 	}
 
@@ -28,7 +30,7 @@ func LoadDockerAuthConfig(image string) (types.AuthConfig, error) {
 
 	authConfig, err := config.GetAuthConfig(hostName)
 	if err != nil {
-		log.Warnf("Could not get auth config from docker config: %v", err)
+		logger.Warnf("Could not get auth config from docker config: %v", err)
 		return types.AuthConfig{}, err
 	}
 
