@@ -112,6 +112,10 @@ jobs:
         password: registry-password
       env:
         HOME: /home/user
+      volumes:
+        - my_docker_volume:/volume_mount
+        - /data/my_data
+        - /source/directory:/destination/directory
     runs-on: ubuntu-latest
     steps:
     - uses: ./actions/docker-url
@@ -127,6 +131,11 @@ jobs:
 	assert.Contains(t, container.Env["HOME"], "/home/user")
 	assert.Contains(t, container.Credentials["username"], "registry-username")
 	assert.Contains(t, container.Credentials["password"], "registry-password")
+	assert.ElementsMatch(t, container.Volumes, []string{
+		"my_docker_volume:/volume_mount",
+		"/data/my_data",
+		"/source/directory:/destination/directory",
+	})
 }
 
 func TestReadWorkflow_StepsTypes(t *testing.T) {
@@ -238,6 +247,7 @@ func TestReadWorkflow_Strategy(t *testing.T) {
 			{"datacenter": "site-c", "node-version": "14.x", "site": "staging"},
 			{"datacenter": "site-c", "node-version": "16.x", "site": "staging"},
 			{"datacenter": "site-d", "node-version": "16.x", "site": "staging"},
+			{"php-version": 5.4},
 			{"datacenter": "site-a", "node-version": "10.x", "site": "prod"},
 			{"datacenter": "site-b", "node-version": "12.x", "site": "dev"},
 		},
